@@ -23,15 +23,14 @@ local_opt = frigidum.sa(random_start=tsp.random_start,
            post_annealing = tsp.local_search_2opt)
 """
 import os
-import inspect
 import re
 import frigidum
 
 import numpy as np
 
 
-FRIGIDUM_PATH = os.path.dirname(inspect.getfile(frigidum))
-TSPLIB_PATH = FRIGIDUM_PATH + '/examples/tsplib/'
+FRIGIDUM_PATH = os.path.dirname( frigidum.__file__ )
+DATA_PATH = FRIGIDUM_PATH + '/data/'
 
 """
 	REGEX taken from https://www.regular-expressions.info/floatingpoint.html
@@ -40,7 +39,7 @@ TSPLIB_PATH = FRIGIDUM_PATH + '/examples/tsplib/'
 """
 re_node_line = re.compile("(\d+) ([0-9]*\.?[0-9]+)([eE][-+]?[0-9]+)? ([0-9]*\.?[0-9]+)([eE][-+]?[0-9]+)?")
 nodes_dict = {}
-pcb442_path = TSPLIB_PATH + 'pcb442.tsp'
+pcb442_path = DATA_PATH + 'pcb442.tsp'
 
 """
 
